CustomEntryLoader

Struct CustomEntryLoader 

pub struct CustomEntryLoader<T> {
    pub loader: T,
    pub get_instance_proc_addr: PFN_vkGetInstanceProcAddr,
    pub create_instance: Option<PFN_vkCreateInstance>,
    pub enumerate_instance_version: Option<PFN_vkEnumerateInstanceVersion>,
    pub enumerate_instance_layer_properties: Option<PFN_vkEnumerateInstanceLayerProperties>,
    pub enumerate_instance_extension_properties: Option<PFN_vkEnumerateInstanceExtensionProperties>,
    /* private fields */
}
Loader for entry commands.

To create a new loader, call EntryLoader::new.

Fields

loader: Tget_instance_proc_addr: PFN_vkGetInstanceProcAddrcreate_instance: Option<PFN_vkCreateInstance>enumerate_instance_version: Option<PFN_vkEnumerateInstanceVersion>enumerate_instance_layer_properties: Option<PFN_vkEnumerateInstanceLayerProperties>enumerate_instance_extension_properties: Option<PFN_vkEnumerateInstanceExtensionProperties>

Implementations

Source

impl<T> CustomEntryLoader<T>

Provided by crate::vk1_0

pub unsafe fn create_instance( &self, create_info: &InstanceCreateInfo, allocator: Option<&AllocationCallbacks>, ) -> VulkanResult<Instance>

Vulkan Manual Page · Function

pub unsafe fn enumerate_instance_layer_properties( &self, property_count: Option<u32>, ) -> VulkanResult<SmallVec<LayerProperties>>

Vulkan Manual Page · Function

pub unsafe fn enumerate_instance_extension_properties( &self, layer_name: Option<&CStr>, property_count: Option<u32>, ) -> VulkanResult<SmallVec<ExtensionProperties>>

Vulkan Manual Page · Function

Source

impl<T> CustomEntryLoader<T>

Provided by crate::vk1_1

Source

impl CustomEntryLoader<Library>

pub fn new() -> Result<EntryLoader, EntryLoaderError>

Load functions using libloading.

Enabled using the loading cargo feature.

For more advanced use cases, take a look at EntryLoader::with_lib_path and EntryLoader::with_library.

pub fn with_lib_path<P: AsRef<OsStr>>( lib_path: P, ) -> Result<EntryLoader, EntryLoaderError>

Load functions using libloading providing a custom library path.

Enabled using the loading cargo feature.

Source

impl<T> CustomEntryLoader<T>

pub unsafe fn with_library( library: T, symbol: impl FnMut(&mut T, *const c_char) -> Option<PFN_vkVoidFunction>, ) -> Result<Self, LoaderError>

Creates a entry loader with a custom library used for loading.

pub fn enabled(&self) -> &EntryEnabled

Access enabled requirements of this entry loader.

pub fn instance_version(&self) -> u32

This will be the result of vkEnumerateInstanceVersion if available, otherwise 0.1.0.0.